#
#  A value. Simple class that manages an atomic variable value.
#
#  { value => string,          -- value
#    file  => file,            -- where defined
#    line  => line,            -- where defined
#    modified => bool }        -- whether it was modified
#
package Value;

use strict;

# Value->new(value, file, line)
# - create new value
sub new {
    my $proto = shift;
    my $value = shift || "";
    my $file  = shift;
    my $line  = shift;
    bless ({ value => $value,
             file  => $file,
             line  => $line,
             modified => 0 },
           ref($proto) || $proto);
}

## Getters
sub getValue {
    shift->{value}
}

sub isModified {
    shift->{modified}
}

sub getFile {
    shift->{file}
}

sub getLine {
    shift->{line}
}

## Setters
sub setModified {
    my $self = shift;
    my $modified = @_ ? shift : 1;
    $self->{modified} = $modified;
}

sub setValue {
    my $self = shift;
    my $value = shift;
    $self->{value} = $value;
}

sub clone {
    my $self = shift;
    my $p = Value->new($self->{value},
                       $self->{file},      # note that we do not clone the file object
                       $self->{line});
    $p->setModified($self->{modified});    # FIXME: really do that?
    $p;
}

1;
